/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.ffxc.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.ffxcLlls.pojo.entity.JwtdFfxcLllsEntity;
import org.springblade.modules.ffxcLlls.service.IJwtdFfxcLllsService;
import org.springblade.modules.system.pojo.entity.DictBiz;
import org.springblade.modules.system.service.IDictBizService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.ffxc.pojo.entity.JwtdFfxcEntity;
import org.springblade.modules.ffxc.pojo.vo.JwtdFfxcVO;
import org.springblade.modules.ffxc.excel.JwtdFfxcExcel;
import org.springblade.modules.ffxc.wrapper.JwtdFfxcWrapper;
import org.springblade.modules.ffxc.service.IJwtdFfxcService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_防范宣传 控制器
 *
 * @author BladeX
 * @since 2024-11-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdFfxc")
@Tag(name = "警务团队_防范宣传", description = "警务团队_防范宣传接口")
public class JwtdFfxcController extends BladeController {

	private final IJwtdFfxcService jwtdFfxcService;

	private final IJwtdFfxcLllsService jwtdFfxcLllsService;

	private final IDictBizService dictBizService;

	/**
	 * 警务团队_防范宣传 平台详情
	 */
	@GetMapping("/detailPt")
	public R<JwtdFfxcEntity> detailPt(JwtdFfxcEntity jwtdFfxc) {
		JwtdFfxcEntity detail = jwtdFfxcService.getById(jwtdFfxc);
		return R.data(detail);
	}

	/**
	 * 警务团队_防范宣传 App详情
	 */
	@GetMapping("/detailApp")
	public R<JwtdFfxcEntity> detailApp(JwtdFfxcEntity jwtdFfxc) {
		JwtdFfxcLllsEntity jfls = new JwtdFfxcLllsEntity();
		jfls.setFfxcId(jwtdFfxc.getId());
		jfls.setUserId(AuthUtil.getUserId());
		jfls.setLlzt("0");
		jfls.setJf(0);
		jwtdFfxcLllsService.save(jfls);
		JwtdFfxcEntity detail = jwtdFfxcService.getById(jwtdFfxc);
		detail.setLsId(jfls.getId());
		return R.data(detail);
	}

	/**
	 * 警务团队_防范宣传 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdFfxc")
	public R<IPage<JwtdFfxcVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdFfxc, Query query) {
		IPage<JwtdFfxcEntity> pages = jwtdFfxcService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdFfxc, JwtdFfxcEntity.class));
		return R.data(JwtdFfxcWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_防范宣传 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdFfxc")
	public R<IPage<JwtdFfxcVO>> page(JwtdFfxcVO jwtdFfxc, Query query) {
		IPage<JwtdFfxcVO> pages = jwtdFfxcService.selectJwtdFfxcPage(Condition.getPage(query), jwtdFfxc);
		return R.data(pages);
	}

	/**
	 * 警务团队_防范宣传 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdFfxc")
	public R save(@Valid @RequestBody JwtdFfxcEntity jwtdFfxc) {
		DictBiz byId = dictBizService.getById(jwtdFfxc.getXclxId());
		jwtdFfxc.setJf(Integer.valueOf(byId.getRemark()));
		return R.status(jwtdFfxcService.save(jwtdFfxc));
	}

	/**
	 * 警务团队_防范宣传 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdFfxc")
	public R update(@Valid @RequestBody JwtdFfxcEntity jwtdFfxc) {
		return R.status(jwtdFfxcService.updateById(jwtdFfxc));
	}

	/**
	 * 警务团队_防范宣传 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdFfxc")
	public R submit(@Valid @RequestBody JwtdFfxcEntity jwtdFfxc) {
		return R.status(jwtdFfxcService.saveOrUpdate(jwtdFfxc));
	}

	/**
	 * 警务团队_防范宣传 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdFfxcService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdFfxc")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdFfxc")
	public void exportJwtdFfxc(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdFfxc, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdFfxcEntity> queryWrapper = Condition.getQueryWrapper(jwtdFfxc, JwtdFfxcEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdFfxcEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdFfxcEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdFfxcExcel> list = jwtdFfxcService.exportJwtdFfxc(queryWrapper);
		ExcelUtil.export(response, "警务团队_防范宣传数据" + DateUtil.time(), "警务团队_防范宣传数据表", list, JwtdFfxcExcel.class);
	}

}
