/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.ffxcLlls.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.jwtdJfjl.pojo.entity.JwtdJfjlEntity;
import org.springblade.modules.jwtdJfjl.service.IJwtdJfjlService;
import org.springblade.modules.system.pojo.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.ffxcLlls.pojo.entity.JwtdFfxcLllsEntity;
import org.springblade.modules.ffxcLlls.pojo.vo.JwtdFfxcLllsVO;
import org.springblade.modules.ffxcLlls.excel.JwtdFfxcLllsExcel;
import org.springblade.modules.ffxcLlls.wrapper.JwtdFfxcLllsWrapper;
import org.springblade.modules.ffxcLlls.service.IJwtdFfxcLllsService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.RoleConstant;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_防范宣传_浏览历史 控制器
 *
 * @author BladeX
 * @since 2024-11-05
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdFfxcLlls")
@Tag(name = "警务团队_防范宣传_浏览历史", description = "警务团队_防范宣传_浏览历史接口")
public class JwtdFfxcLllsController extends BladeController {

	private final IJwtdFfxcLllsService jwtdFfxcLllsService;

	private final IUserService userService;

	private final IJwtdJfjlService jwtdJfjlService;

	/**
	 * 警务团队_防范宣传_浏览历史 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdFfxcLlls")
	public R<JwtdFfxcLllsVO> detail(JwtdFfxcLllsEntity jwtdFfxcLlls) {
		JwtdFfxcLllsEntity detail = jwtdFfxcLllsService.getOne(Condition.getQueryWrapper(jwtdFfxcLlls));
		return R.data(JwtdFfxcLllsWrapper.build().entityVO(detail));
	}

	/**
	 * 警务团队_防范宣传_浏览历史 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdFfxcLlls")
	public R<IPage<JwtdFfxcLllsVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdFfxcLlls, Query query) {
		IPage<JwtdFfxcLllsEntity> pages = jwtdFfxcLllsService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdFfxcLlls, JwtdFfxcLllsEntity.class));
		return R.data(JwtdFfxcLllsWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_防范宣传_浏览历史 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdFfxcLlls")
	public R<IPage<JwtdFfxcLllsVO>> page(JwtdFfxcLllsVO jwtdFfxcLlls, Query query) {
		IPage<JwtdFfxcLllsVO> pages = jwtdFfxcLllsService.selectJwtdFfxcLllsPage(Condition.getPage(query), jwtdFfxcLlls);
		return R.data(pages);
	}

	/**
	 * 警务团队_防范宣传_浏览历史 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdFfxcLlls")
	public R save(@Valid @RequestBody JwtdFfxcLllsEntity jwtdFfxcLlls) {
		jwtdFfxcLlls.setUserId(AuthUtil.getUserId());
		return R.status(jwtdFfxcLllsService.save(jwtdFfxcLlls));
	}

	/**
	 * 警务团队_防范宣传_浏览历史 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdFfxcLlls")
	public R update(@Valid @RequestBody JwtdFfxcLllsEntity jwtdFfxcLlls) {
		JwtdJfjlEntity jwtdJfjl = new JwtdJfjlEntity();
		jwtdJfjl.setUserId(AuthUtil.getUserId());
		jwtdJfjl.setType("1");
		jwtdJfjl.setJfId(jwtdFfxcLlls.getFfxcId());
		jwtdJfjl.setJf(jwtdFfxcLlls.getJf());
		jwtdJfjlService.save(jwtdJfjl);
		jwtdFfxcLlls.setUserId(AuthUtil.getUserId());
		List<JwtdFfxcLllsEntity> llls = jwtdFfxcLllsService.selectLllsByUserIdAndFfxcId(jwtdFfxcLlls);
		for (JwtdFfxcLllsEntity ryls : llls) {
			if (ryls.getLlzt().equals("1") && ryls.getJf() != 0) {
				jwtdFfxcLlls.setJf(0);
				break;
			}
		}
		if (jwtdFfxcLlls.getJf() != 0) {
			User user = userService.getById(AuthUtil.getUserId());
			Integer jf = user.getJf() + jwtdFfxcLlls.getJf();
			user.setJf(jf);
			userService.updateById(user);
		}
		return R.status(jwtdFfxcLllsService.updateById(jwtdFfxcLlls));
	}

	/**
	 * 警务团队_防范宣传_浏览历史 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdFfxcLlls")
	public R submit(@Valid @RequestBody JwtdFfxcLllsEntity jwtdFfxcLlls) {
		return R.status(jwtdFfxcLllsService.saveOrUpdate(jwtdFfxcLlls));
	}

	/**
	 * 警务团队_防范宣传_浏览历史 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdFfxcLllsService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdFfxcLlls")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdFfxcLlls")
	public void exportJwtdFfxcLlls(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdFfxcLlls, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdFfxcLllsEntity> queryWrapper = Condition.getQueryWrapper(jwtdFfxcLlls, JwtdFfxcLllsEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdFfxcLllsEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdFfxcLllsEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdFfxcLllsExcel> list = jwtdFfxcLllsService.exportJwtdFfxcLlls(queryWrapper);
		ExcelUtil.export(response, "警务团队_防范宣传_浏览历史数据" + DateUtil.time(), "警务团队_防范宣传_浏览历史数据表", list, JwtdFfxcLllsExcel.class);
	}

	/**
	 * 防范宣传浏览记录
	 */
	@GetMapping("getFfxcLljl")
	public R getFfxcLljl(Long id) {
		return R.data(jwtdFfxcLllsService.getFfxcLljl(id));
	}
}
