/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.jwtdJfjl.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.pojo.entity.User;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.jwtdJfjl.pojo.entity.JwtdJfjlEntity;
import org.springblade.modules.jwtdJfjl.pojo.vo.JwtdJfjlVO;
import org.springblade.modules.jwtdJfjl.excel.JwtdJfjlExcel;
import org.springblade.modules.jwtdJfjl.wrapper.JwtdJfjlWrapper;
import org.springblade.modules.jwtdJfjl.service.IJwtdJfjlService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_积分记录 控制器
 *
 * @author BladeX
 * @since 2024-11-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdJfjl")
@Tag(name = "警务团队_积分记录", description = "警务团队_积分记录接口")
public class JwtdJfjlController extends BladeController {

	private final IJwtdJfjlService jwtdJfjlService;

	/**
	 * 警务团队_积分记录 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdJfjl")
	public R<JwtdJfjlVO> detail(JwtdJfjlEntity jwtdJfjl) {
		JwtdJfjlEntity detail = jwtdJfjlService.getOne(Condition.getQueryWrapper(jwtdJfjl));
		return R.data(JwtdJfjlWrapper.build().entityVO(detail));
	}

	/**
	 * 警务团队_积分记录 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdJfjl")
	public R<IPage<JwtdJfjlVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdJfjl, Query query) {
		IPage<JwtdJfjlEntity> pages = jwtdJfjlService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdJfjl, JwtdJfjlEntity.class));
		return R.data(JwtdJfjlWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_积分记录 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdJfjl")
	public R<IPage<JwtdJfjlVO>> page(JwtdJfjlVO jwtdJfjl, Query query) {
		IPage<JwtdJfjlVO> pages = jwtdJfjlService.selectJwtdJfjlPage(Condition.getPage(query), jwtdJfjl);
		return R.data(pages);
	}

	/**
	 * 警务团队_积分记录 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdJfjl")
	public R save(@Valid @RequestBody JwtdJfjlEntity jwtdJfjl) {
		return R.status(jwtdJfjlService.save(jwtdJfjl));
	}

	/**
	 * 警务团队_积分记录 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdJfjl")
	public R update(@Valid @RequestBody JwtdJfjlEntity jwtdJfjl) {
		return R.status(jwtdJfjlService.updateById(jwtdJfjl));
	}

	/**
	 * 警务团队_积分记录 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdJfjl")
	public R submit(@Valid @RequestBody JwtdJfjlEntity jwtdJfjl) {
		return R.status(jwtdJfjlService.saveOrUpdate(jwtdJfjl));
	}

	/**
	 * 警务团队_积分记录 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdJfjlService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdJfjl")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdJfjl")
	public void exportJwtdJfjl(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdJfjl, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdJfjlEntity> queryWrapper = Condition.getQueryWrapper(jwtdJfjl, JwtdJfjlEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdJfjlEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdJfjlEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdJfjlExcel> list = jwtdJfjlService.exportJwtdJfjl(queryWrapper);
		ExcelUtil.export(response, "警务团队_积分记录数据" + DateUtil.time(), "警务团队_积分记录数据表", list, JwtdJfjlExcel.class);
	}

	/**
	 * 积分明细
	 */
	@GetMapping("getJlList")
	public R getJlList(String type) {
		return R.data(jwtdJfjlService.getJlList(type, AuthUtil.getUserId()));
	}

	/**
	 * 获取记录
	 */
	@GetMapping("getHqjl")
	public R getHqjl(Long userId) {
		return R.data(jwtdJfjlService.getHqjl(userId));
	}

	/**
	 * 兑换记录
	 */
	@GetMapping("getDhjl")
	public R getDhjl(Long userId) {
		return R.data(jwtdJfjlService.getDhjl(userId));
	}
}
