/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.jwtdJwgk.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.pojo.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.jwtdJwgk.pojo.entity.JwtdJwgkEntity;
import org.springblade.modules.jwtdJwgk.pojo.vo.JwtdJwgkVO;
import org.springblade.modules.jwtdJwgk.excel.JwtdJwgkExcel;
import org.springblade.modules.jwtdJwgk.wrapper.JwtdJwgkWrapper;
import org.springblade.modules.jwtdJwgk.service.IJwtdJwgkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_警务公开 控制器
 *
 * @author BladeX
 * @since 2024-11-06
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdJwgk")
@Tag(name = "警务团队_警务公开", description = "警务团队_警务公开接口")
public class JwtdJwgkController extends BladeController {

	private final IJwtdJwgkService jwtdJwgkService;

	private final IUserService userService;

	/**
	 * 警务团队_警务公开 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdJwgk")
	public R<JwtdJwgkVO> detail(JwtdJwgkEntity jwtdJwgk) {
		JwtdJwgkEntity detail = jwtdJwgkService.getOne(Condition.getQueryWrapper(jwtdJwgk));
		return R.data(JwtdJwgkWrapper.build().entityVO(detail));
	}

	/**
	 * 警务团队_警务公开 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdJwgk")
	public R<IPage<JwtdJwgkVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdJwgk, Query query) {
		IPage<JwtdJwgkEntity> pages = jwtdJwgkService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdJwgk, JwtdJwgkEntity.class));
		return R.data(JwtdJwgkWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_警务公开 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdJwgk")
	public R<IPage<JwtdJwgkVO>> page(JwtdJwgkVO jwtdJwgk, Query query) {
		IPage<JwtdJwgkVO> pages = jwtdJwgkService.selectJwtdJwgkPage(Condition.getPage(query), jwtdJwgk);
		return R.data(pages);
	}

	/**
	 * 警务团队_警务公开 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdJwgk")
	public R save(@Valid @RequestBody JwtdJwgkEntity jwtdJwgk) {
		JwtdJwgkEntity jh = jwtdJwgkService.selectJh(jwtdJwgk.getJh());
		if (jh != null) {
			return R.fail("已有该警号，请重新输入警号");
		}
		return R.status(jwtdJwgkService.save(jwtdJwgk));
	}

	/**
	 * 警务团队_警务公开 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdJwgk")
	public R update(@Valid @RequestBody JwtdJwgkEntity jwtdJwgk) {
		return R.status(jwtdJwgkService.updateById(jwtdJwgk));
	}

	/**
	 * 警务团队_警务公开 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdJwgk")
	public R submit(@Valid @RequestBody JwtdJwgkEntity jwtdJwgk) {
		return R.status(jwtdJwgkService.saveOrUpdate(jwtdJwgk));
	}

	/**
	 * 警务团队_警务公开 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdJwgkService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdJwgk")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdJwgk")
	public void exportJwtdJwgk(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdJwgk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdJwgkEntity> queryWrapper = Condition.getQueryWrapper(jwtdJwgk, JwtdJwgkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdJwgkEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdJwgkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdJwgkExcel> list = jwtdJwgkService.exportJwtdJwgk(queryWrapper);
		ExcelUtil.export(response, "警务团队_警务公开数据" + DateUtil.time(), "警务团队_警务公开数据表", list, JwtdJwgkExcel.class);
	}

}
