/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.jwtdSpgl.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.jwtdSpglBhjl.pojo.entity.JwtdSpglBhjlEntity;
import org.springblade.modules.jwtdSpglBhjl.service.IJwtdSpglBhjlService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.jwtdSpgl.pojo.entity.JwtdSpglEntity;
import org.springblade.modules.jwtdSpgl.pojo.vo.JwtdSpglVO;
import org.springblade.modules.jwtdSpgl.excel.JwtdSpglExcel;
import org.springblade.modules.jwtdSpgl.wrapper.JwtdSpglWrapper;
import org.springblade.modules.jwtdSpgl.service.IJwtdSpglService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_商品管理 控制器
 *
 * @author BladeX
 * @since 2024-11-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdSpgl")
@Tag(name = "警务团队_商品管理", description = "警务团队_商品管理接口")
public class JwtdSpglController extends BladeController {

	private final IJwtdSpglService jwtdSpglService;

	private final IJwtdSpglBhjlService jwtdSpglBhjlService;

	/**
	 * 警务团队_商品管理 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdSpgl")
	public R<JwtdSpglVO> detail(JwtdSpglEntity jwtdSpgl) {
		JwtdSpglEntity detail = jwtdSpglService.getOne(Condition.getQueryWrapper(jwtdSpgl));
		List<JwtdSpglBhjlEntity> bhjlList = jwtdSpglBhjlService.selectBhjl(jwtdSpgl.getId());
		detail.setBhjlList(bhjlList);
		return R.data(JwtdSpglWrapper.build().entityVO(detail));
	}

	/**
	 * 警务团队_商品管理 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdSpgl")
	public R<IPage<JwtdSpglVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdSpgl, Query query) {
		IPage<JwtdSpglEntity> pages = jwtdSpglService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdSpgl, JwtdSpglEntity.class));
		return R.data(JwtdSpglWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_商品管理 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdSpgl")
	public R<IPage<JwtdSpglVO>> page(JwtdSpglVO jwtdSpgl, Query query) {
		IPage<JwtdSpglVO> pages = jwtdSpglService.selectJwtdSpglPage(Condition.getPage(query), jwtdSpgl);
		return R.data(pages);
	}

	/**
	 * 警务团队_商品管理 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdSpgl")
	public R save(@Valid @RequestBody JwtdSpglEntity jwtdSpgl) {
		JwtdSpglBhjlEntity jwtdSpglBhjl = new JwtdSpglBhjlEntity();
		jwtdSpglBhjl.setSpId(jwtdSpgl.getId());
		jwtdSpglBhjl.setKcl(jwtdSpgl.getSpkcl());
		jwtdSpglBhjlService.save(jwtdSpglBhjl);
		return R.status(jwtdSpglService.save(jwtdSpgl));
	}

	/**
	 * 警务团队_商品管理 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdSpgl")
	public R update(@Valid @RequestBody JwtdSpglEntity jwtdSpgl) {
		return R.status(jwtdSpglService.updateById(jwtdSpgl));
	}

	/**
	 * 警务团队_商品管理 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdSpgl")
	public R submit(@Valid @RequestBody JwtdSpglEntity jwtdSpgl) {
		return R.status(jwtdSpglService.saveOrUpdate(jwtdSpgl));
	}

	/**
	 * 警务团队_商品管理 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdSpglService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdSpgl")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdSpgl")
	public void exportJwtdSpgl(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdSpgl, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdSpglEntity> queryWrapper = Condition.getQueryWrapper(jwtdSpgl, JwtdSpglEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdSpglEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdSpglEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdSpglExcel> list = jwtdSpglService.exportJwtdSpgl(queryWrapper);
		ExcelUtil.export(response, "警务团队_商品管理数据" + DateUtil.time(), "警务团队_商品管理数据表", list, JwtdSpglExcel.class);
	}

	/**
	 * 商品补货
	 */
	@PostMapping("spbh")
	public R spbh(@RequestBody JwtdSpglEntity jwtdSpgl) {
		JwtdSpglBhjlEntity jwtdSpglBhjl = new JwtdSpglBhjlEntity();
		jwtdSpglBhjl.setSpId(jwtdSpgl.getId());
		jwtdSpglBhjl.setKcl(jwtdSpgl.getSpkcl() + jwtdSpgl.getBhl());
		jwtdSpglBhjl.setBhl(jwtdSpgl.getBhl());
		jwtdSpglBhjlService.save(jwtdSpglBhjl);
		return R.status(jwtdSpglService.updateById(jwtdSpgl));
	}
}
