/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.jwtdSpglDhjl.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.jwtdJfjl.pojo.entity.JwtdJfjlEntity;
import org.springblade.modules.jwtdJfjl.service.IJwtdJfjlService;
import org.springblade.modules.jwtdSpgl.pojo.entity.JwtdSpglEntity;
import org.springblade.modules.jwtdSpgl.service.IJwtdSpglService;
import org.springblade.modules.system.pojo.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springblade.modules.utils.OrderCodeFactory;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.jwtdSpglDhjl.pojo.entity.JwtdSpglDhjlEntity;
import org.springblade.modules.jwtdSpglDhjl.pojo.vo.JwtdSpglDhjlVO;
import org.springblade.modules.jwtdSpglDhjl.excel.JwtdSpglDhjlExcel;
import org.springblade.modules.jwtdSpglDhjl.service.IJwtdSpglDhjlService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.RoleConstant;

import java.util.Date;
import java.util.Map;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;

/**
 * 警务团队_商品管理_兑换记录 控制器
 *
 * @author BladeX
 * @since 2024-11-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdSpglDhjl")
@Tag(name = "警务团队_商品管理_兑换记录", description = "警务团队_商品管理_兑换记录接口")
public class JwtdSpglDhjlController extends BladeController {

	private final IJwtdSpglDhjlService jwtdSpglDhjlService;

	private final IJwtdSpglService jwtdSpglService;

	private final IUserService userService;

	private final IJwtdJfjlService jwtdJfjlService;

	/**
	 * 警务团队_商品管理_兑换记录 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdSpglDhjl")
	public R detail(JwtdSpglDhjlEntity jwtdSpglDhjl) {
		JwtdSpglDhjlEntity detail = jwtdSpglDhjlService.detailByDdbh(jwtdSpglDhjl);
		List<JwtdSpglDhjlVO> spList = jwtdSpglDhjlService.detailListByDdbh(jwtdSpglDhjl);
		return R.data(detail);
	}


	/**
	 * 警务团队_商品管理_兑换记录 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdSpglDhjl")
	public R<IPage<JwtdSpglDhjlEntity>> page(JwtdSpglDhjlEntity jwtdSpglDhjl, Query query) {
		IPage<JwtdSpglDhjlEntity> pages = jwtdSpglDhjlService.selectJwtdSpglDhjlPage(Condition.getPage(query), jwtdSpglDhjl);
		return R.data(pages);
	}

	/**
	 * 警务团队_商品管理_兑换记录 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdSpglDhjl")
	public R save(@Valid @RequestBody JwtdSpglDhjlEntity jwtdSpglDhjl) {
		return R.status(jwtdSpglDhjlService.save(jwtdSpglDhjl));
	}

	/**
	 * 警务团队_商品管理_兑换记录 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdSpglDhjl")
	public R update(@Valid @RequestBody JwtdSpglDhjlEntity jwtdSpglDhjl) {
		return R.status(jwtdSpglDhjlService.updateById(jwtdSpglDhjl));
	}

	/**
	 * 警务团队_商品管理_兑换记录 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdSpglDhjl")
	public R submit(@Valid @RequestBody JwtdSpglDhjlEntity jwtdSpglDhjl) {
		return R.status(jwtdSpglDhjlService.saveOrUpdate(jwtdSpglDhjl));
	}

	/**
	 * 警务团队_商品管理_兑换记录 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdSpglDhjlService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdSpglDhjl")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdSpglDhjl")
	public void exportJwtdSpglDhjl(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdSpglDhjl, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdSpglDhjlEntity> queryWrapper = Condition.getQueryWrapper(jwtdSpglDhjl, JwtdSpglDhjlEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdSpglDhjlEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JwtdSpglDhjlEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdSpglDhjlExcel> list = jwtdSpglDhjlService.exportJwtdSpglDhjl(queryWrapper);
		ExcelUtil.export(response, "警务团队_商品管理_兑换记录数据" + DateUtil.time(), "警务团队_商品管理_兑换记录数据表", list, JwtdSpglDhjlExcel.class);
	}

	/**
	 * 购物车结算
	 */
	@PostMapping("gwcjs")
	public R gwcjs(@RequestBody List<JwtdSpglDhjlEntity> gwc) {
		String orderCode = OrderCodeFactory.getOrderCode(AuthUtil.getUserId());
		Date date = new Date();
		for (JwtdSpglDhjlEntity jwtdSpglDhjl : gwc) {
			JwtdSpglEntity byId = jwtdSpglService.getById(jwtdSpglDhjl.getSpId());
			if (byId.getSpkcl() < jwtdSpglDhjl.getCount()) {
				return R.fail("库存量不足");
			}
			JwtdSpglEntity spgl = new JwtdSpglEntity();
			spgl.setId(byId.getId());
			spgl.setSpkcl(byId.getSpkcl() - jwtdSpglDhjl.getCount());
			spgl.setSpydhsl(byId.getSpydhsl() + jwtdSpglDhjl.getCount());
			jwtdSpglService.updateById(spgl);
			User user = userService.getById(AuthUtil.getUserId());
			User jf = new User();
			jf.setId(user.getId());
			jf.setJf(user.getJf() - jwtdSpglDhjl.getJf());
			userService.updateById(jf);
			JwtdSpglDhjlEntity dh = new JwtdSpglDhjlEntity();
			dh.setDdbh(orderCode);
			dh.setUserId(AuthUtil.getUserId());
			dh.setSpId(byId.getId());
			dh.setSpsl(jwtdSpglDhjl.getSpsl());
			dh.setXhjf(jwtdSpglDhjl.getXhjf());
			dh.setLqzt("0");
			dh.setCreateTime(date);
			dh.setUpdateTime(date);
			jwtdSpglDhjlService.save(dh);
			JwtdJfjlEntity jwtdJfjl = new JwtdJfjlEntity();
			jwtdJfjl.setUserId(AuthUtil.getUserId());
			jwtdJfjl.setType("2");
			jwtdJfjl.setJfId(dh.getId());
			jwtdJfjl.setJf(dh.getXhjf());
			jwtdJfjlService.save(jwtdJfjl);
		}
		return R.data("操作成功");
	}

	/**
	 * 商品发货
	 */
	@PostMapping("spfh")
	public R spfh(@RequestBody String ddbh) {
		return R.data(jwtdSpglDhjlService.updateLqzt(ddbh, AuthUtil.getUserId(), AuthUtil.getDeptId()));
	}

	/**
	 * 我的订单
	 */
	@GetMapping("getDdList")
	public R getDdList(String type, String spmc) {
		return R.data(jwtdSpglDhjlService.getDdList(type, AuthUtil.getUserId(), spmc));
	}
}
