/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * THIS SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY. The author is
 * not liable for any claims arising from secondary or illegal development.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.modules.szqyJyz.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import jakarta.validation.Valid;

import org.apache.commons.lang3.StringUtils;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.pojo.entity.Dept;
import org.springblade.modules.system.service.IDeptService;
import org.springblade.modules.szqyCsjl.pojo.entity.JwtdSzqyCsjlEntity;
import org.springblade.modules.szqyJyz.utils.ExcelUtils;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.szqyJyz.pojo.entity.JwtdSzqyJyzEntity;
import org.springblade.modules.szqyJyz.pojo.vo.JwtdSzqyJyzVO;
import org.springblade.modules.szqyJyz.excel.JwtdSzqyJyzExcel;
import org.springblade.modules.szqyJyz.wrapper.JwtdSzqyJyzWrapper;
import org.springblade.modules.szqyJyz.service.IJwtdSzqyJyzService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.constant.RoleConstant;

import java.util.*;

import jakarta.servlet.http.HttpServletResponse;
import org.springframework.web.multipart.MultipartFile;

/**
 * 警务团队_散装汽油_加油站详情 控制器
 *
 * @author BladeX
 * @since 2024-10-31
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jwtdSzqyJyz")
@Tag(name = "警务团队_散装汽油_加油站详情", description = "警务团队_散装汽油_加油站详情接口")
public class JwtdSzqyJyzController extends BladeController {

	private final IJwtdSzqyJyzService jwtdSzqyJyzService;

	private final IDeptService deptService;

	/**
	 * 警务团队_散装汽油_加油站详情 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@Operation(summary = "详情", description  = "传入jwtdSzqyJyz")
	public R detail(JwtdSzqyJyzEntity jwtdSzqyJyz) {
		JwtdSzqyJyzEntity detail = jwtdSzqyJyzService.getById(jwtdSzqyJyz.getId());
		List<JwtdSzqyCsjlEntity> csjlList = jwtdSzqyJyzService.selectCsjlById(jwtdSzqyJyz.getShtyxydm());
		detail.setCsjlList(csjlList);
		return R.data(detail);
	}

	/**
	 * 警务团队_散装汽油_加油站详情 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@Operation(summary = "分页", description  = "传入jwtdSzqyJyz")
	public R<IPage<JwtdSzqyJyzVO>> list(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdSzqyJyz, Query query) {
		IPage<JwtdSzqyJyzEntity> pages = jwtdSzqyJyzService.page(Condition.getPage(query), Condition.getQueryWrapper(jwtdSzqyJyz, JwtdSzqyJyzEntity.class));
		return R.data(JwtdSzqyJyzWrapper.build().pageVO(pages));
	}


	/**
	 * 警务团队_散装汽油_加油站详情 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@Operation(summary = "分页", description  = "传入jwtdSzqyJyz")
	public R<IPage<JwtdSzqyJyzVO>> page(JwtdSzqyJyzVO jwtdSzqyJyz, Query query) {
		IPage<JwtdSzqyJyzVO> pages = jwtdSzqyJyzService.selectJwtdSzqyJyzPage(Condition.getPage(query), jwtdSzqyJyz);
		return R.data(pages);
	}

	/**
	 * 警务团队_散装汽油_加油站详情 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@Operation(summary = "新增", description  = "传入jwtdSzqyJyz")
	public R save(@Valid @RequestBody JwtdSzqyJyzEntity jwtdSzqyJyz) {
		return R.status(jwtdSzqyJyzService.save(jwtdSzqyJyz));
	}

	/**
	 * 警务团队_散装汽油_加油站详情 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@Operation(summary = "修改", description  = "传入jwtdSzqyJyz")
	public R update(@Valid @RequestBody JwtdSzqyJyzEntity jwtdSzqyJyz) {
		return R.status(jwtdSzqyJyzService.updateById(jwtdSzqyJyz));
	}

	/**
	 * 警务团队_散装汽油_加油站详情 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@Operation(summary = "新增或修改", description  = "传入jwtdSzqyJyz")
	public R submit(@Valid @RequestBody JwtdSzqyJyzEntity jwtdSzqyJyz) {
		return R.status(jwtdSzqyJyzService.saveOrUpdate(jwtdSzqyJyz));
	}

	/**
	 * 警务团队_散装汽油_加油站详情 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@Operation(summary = "逻辑删除", description  = "传入ids")
	public R remove(@Parameter(description = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jwtdSzqyJyzService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jwtdSzqyJyz")
	@ApiOperationSupport(order = 8)
	@Operation(summary = "导出数据", description  = "传入jwtdSzqyJyz")
	public void exportJwtdSzqyJyz(@Parameter(hidden = true) @RequestParam Map<String, Object> jwtdSzqyJyz, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JwtdSzqyJyzEntity> queryWrapper = Condition.getQueryWrapper(jwtdSzqyJyz, JwtdSzqyJyzEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JwtdSzqyJyzEntity::getTenantId, bladeUser.getTenantId());
		//}
		//  queryWrapper.lambda().eq(JwtdSzqyJyzEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JwtdSzqyJyzExcel> list = jwtdSzqyJyzService.exportJwtdSzqyJyz(queryWrapper);
		ExcelUtil.export(response, "警务团队_散装汽油_加油站详情数据" + DateUtil.time(), "警务团队_散装汽油_加油站详情数据表", list, JwtdSzqyJyzExcel.class);
	}

	/**
	 * 加油站下载模板
	 */
	@PostMapping("jyzxzmb")
	public void jyzxzmb(HttpServletResponse response) {
		List<Object> head = Arrays.asList("加油站名称", "社会统一信用代码", "法人姓名", "法人电话", "负责人姓名", "负责人电话", "加油站地址", "管辖地派出所", "管辖地社区");
		List<List<Object>> list = new ArrayList<>();
		list.add(head);
		Map<Integer, List<String>> listMap = new HashMap<>();
		String pcs = deptService.selectPcs(AuthUtil.getDeptId());
		String sq = deptService.selectSq(AuthUtil.getDeptId());
		listMap.put(7, Arrays.asList(pcs));
		listMap.put(8, Arrays.asList(sq));
		ExcelUtils.export(response, "加油站模板", list, listMap);
	}

	/**
	 * 加油站导入
	 */
	@PostMapping("jyzdr")
	public R<Boolean> jyzdr(MultipartFile file) {
		List<JwtdSzqyJyzEntity> jyzList = new ArrayList<>();
		List<JwtdSzqyJyzExcel> list = ExcelUtil.read(file, JwtdSzqyJyzExcel.class);
		for (JwtdSzqyJyzExcel jyzExcel : list) {
			if (StringUtils.isBlank(jyzExcel.getShtyxydm())) {
				return R.fail("社会统一信用代码为空,请重新填写");
			}
			Dept sspcsBm = deptService.selectSspcsBm(jyzExcel.getSspcs());
			Dept sssqBm = deptService.selectSssqBm(jyzExcel.getSssq(), sspcsBm.getId());
			jyzExcel.setSspcs(sspcsBm.getId().toString());
			jyzExcel.setSssq(sssqBm.getId().toString());
			JwtdSzqyJyzEntity jyz = BeanUtil.copy(jyzExcel, JwtdSzqyJyzEntity.class);
			jyzList.add(jyz);
		}
		return R.data(jwtdSzqyJyzService.saveBatch(jyzList));
	}
}
