package org.springblade.modules.utils;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Random;

/**
 * 订单编码码生成器，生成32位数字编码，
 * @生成规则 1位单号类型+17位时间戳+14位(用户id加密&随机数)
 * Date:2017年9月8日上午10:05:19
 * @author jiwengjian
 */
public class OrderCodeFactory {

	/** 订单类别头 */
	private static final String ORDER_CODE = "2";
	/** 随即编码 */
	private static final int[] r = new int[]{7, 9, 6, 2, 8 , 1, 3, 0, 5, 4};
	/** 用户id和随机数总长度 */
	private static final int maxLength = 6;

	/**
	 * 更具id进行加密+加随机数组成固定长度编码
	 */
	private static String toCode(Long id) {
		int subStrLength = 4;
		int length = id.toString().length();
		String str;
		if (length >= subStrLength) {
			str = id.toString().substring(length - subStrLength, length);
		} else {
			str = String.format("%0" + subStrLength + "d", id.toString());
		}
		String idStr = str.toString();
		StringBuilder idsbs = new StringBuilder();
		for (int i = idStr.length() - 1 ; i >= 0; i--) {
			idsbs.append(r[idStr.charAt(i)-'0']);
		}
		return idsbs.append(getRandom(maxLength - idStr.length())).toString();
	}

	/**
	 * 生成时间戳
	 */
	private static String getDateTime(){
		DateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmssSSS");
		return sdf.format(new Date());
	}

	/**
	 * 生成固定长度随机码
	 * @param n    长度
	 */
	private static long getRandom(long n) {
		long min = 1,max = 9;
		for (int i = 1; i < n; i++) {
			min *= 10;
			max *= 10;
		}
		long rangeLong = (((long) (new Random().nextDouble() * (max - min)))) + min ;
		return rangeLong;
	}

	/**
	 * 生成不带类别标头的编码
	 * @param userId
	 */
	private static synchronized String getCode(Long userId){
		userId = userId == null ? 10000 : userId;
		return getDateTime() + toCode(userId);
	}

	/**
	 * 生成订单单号编码
	 * @param userId
	 */
	public static String getOrderCode(Long userId){
		return ORDER_CODE + getCode(userId);
	}
}

